% the program returns a system of equations for the value functions
% given a vector of value functions V, market tightness theta and a set of parameters
% the vector of value functions is V = [V^NB; V^B0; V^S2; V^B1; V^S1; V; V^A]  
% B is a vector of flow utilities. eta is the seller bargaining power
% mu and q are the matching rates for sellers and buyers, respectively. 
% r is the discount rate and g is the exit/entry rate

function y = getValues(Vs, theta, B, eta, mu, q, r, g, gamma)

% matrix that describes the surpluses. Each row gives a surplus. Surpluses
% are stacked in the following order: Sigma_S2NB, Sigma_ANB, Sigma_S1NB, Sigma_S2B0, Sigma_AB0, Sigma_S1B0, 
% Sigma_S2B1, Sigma_AB1, Sigma_S1B1
Sigma_matrix = [-1, 0, -1, 0, 0, 2, 0; -1, 0, 0, 0, 0, 1, -1; -1, 1, 0, 0, -1, 1, 0;... 
                0, -1, -1, 0, 0, 2, 0; 0, -1, 0, 0, 0, 1, -1; 0, 0, 0, 0, -1, 1, 0;...
                0, 0, 0, -1, 0, 1, 0; 0, 0, 1, -1, 0, 0, -1; 0, 1, 1, -1, -1, 0, 0];
            
Sigmas = Sigma_matrix*Vs;

rho = r+g;

if theta>1
    % "buy first" equilibrium
    
    % continuation values
    A = [(1-eta)*q(theta)*((mu(theta)-q(theta))/(g+mu(theta))*max(Sigmas(1), 0)+(g+q(theta))/(g+mu(theta))*max(Sigmas(2), 0));...
         (1-eta)*q(theta)*((mu(theta)-q(theta))/(g+mu(theta))*max(Sigmas(4), 0)+(g+q(theta))/(g+mu(theta))*max(Sigmas(5), 0));...
         eta*mu(theta)*(1/theta*max(Sigmas(1), 0)+(theta-1)/theta*max(Sigmas(7), 0));...
         (1-eta)*q(theta)*((mu(theta)-q(theta))/(g+mu(theta))*max(Sigmas(7), 0)+(g+q(theta))/(g+mu(theta))*max(Sigmas(8), 0));...
         eta*mu(theta)*(1/theta*max(Sigmas(3), 0)+(theta-1)/theta*max(Sigmas(9), 0));...
         gamma*(max(Vs(4), Vs(5))-Vs(6));...
         eta*mu(theta)*(1/theta*max(Sigmas(2), 0)+(theta-1)/theta*max(Sigmas(8), 0))];
         
    y = B + A - rho*Vs;
    
else
    % "sell first" equilibrium
    
    % continuation values
    A = [(1-eta)*q(theta)*((1-theta)*max(Sigmas(3), 0)+theta*max(Sigmas(2), 0));...
         (1-eta)*q(theta)*((1-theta)*max(Sigmas(6), 0)+theta*max(Sigmas(5), 0));...
         eta*mu(theta)*((g+mu(theta))/(g+q(theta))*max(Sigmas(1), 0)+(q(theta)-mu(theta))/(g+q(theta))*max(Sigmas(4), 0));...
         (1-eta)*q(theta)*((1-theta)*max(Sigmas(9), 0)+theta*max(Sigmas(8), 0));...
         eta*mu(theta)*((g+mu(theta))/(g+q(theta))*max(Sigmas(3), 0)+(q(theta)-mu(theta))/(g+q(theta))*max(Sigmas(6), 0));...
         gamma*(max(Vs(4), Vs(5))-Vs(6));...
         eta*mu(theta)*((g+mu(theta))/(g+q(theta))*max(Sigmas(2), 0)+(q(theta)-mu(theta))/(g+q(theta))*max(Sigmas(5), 0))];
    
    
    y = B + A - rho*Vs;
     
end

end
    