% the program computes the equilibrium market tightnesses, value functions
% and prices for the model with Nash bargaining and replicates Figure 5 in
% the paper "Buying First or Selling First in Housing Markets" by Moen,
% Nenov, and Sniekers. 

clc;
clear;

% Parameters --------------------------------------------------------------

% matching function
alpha = .84;
m = 3.1;

% matching rates
mu = @(x) m*x.^alpha;
q = @(x) mu(x)./x;

% preferences
r = .05;
u = 2;
u0 = 1.55;
u2 = 1.85;
un = 1.7;
chi = .14;

% rental rate
R = 0.1;

% flow rates
g = .0371;
gamma = .0322;


% seller bargaining power, eta = .5 for symmetric NB
eta = .5;

% effective discount rate
rho = r;


% Solve for theta_upper_bar and theta_lower_bar
% equations for theta_upper_bar and theta_lower_bar
f1 = @(x) (1/(q(x)+g)+1/gamma)*x+(1/(q(x)+g)-1/(mu(x)+g))-1/g-1/gamma;
f2 = @(x) (1/(mu(x)+g)+1/gamma)*(1/x)-1/g-1/gamma;

% Solve for theta_upper_bar (theta1) and theta_lower_bar (theta2)
th1 = fsolve(f1, 1);
th2 = fsolve(f2, 1);

% Flow utilities
B = [un-R; u0-R; u2+R; u-chi; u-chi; u; R];

%% Compute steady state value functions for different values of theta

thetas = [.25:.01:1/.25]; % a grid of values for theta

Ds = zeros(1, length(thetas)); % stores the difference between V^B1 and V^S1 at different values of theta
Vs = zeros(7, length(thetas)); % stores the steady state value functions given theta. for theta>1 conjectures a "buy first" equilibrium and for theta<1 conjectures a "sell first" equilibrium
ps = zeros(9, length(thetas)); % stores the prices from bilateral transactions between buyers and sellers
ave_price = zeros(1, length(thetas)); % stores the average price from transacting

isEquilibrium = zeros(1, length(thetas)); % stores a vector of zeros and ones, with one if an equilibrium exists for the respective value of theta and zero otherwise

V_old = B/rho;

% Solve for steady state value functions, prices, and checks equilibrium
% conditions for all values of theta in the vector thetas
for i = 1:length(thetas)

theta = thetas(i);

% Solve for the value functions given theta
x = fsolve(@(x) getValues(x, theta, B, eta, mu, q, r, g, gamma), V_old, optimset('MaxFunEvals', 10000, 'MaxIter', 10000));

Ds(i) = x(4)-x(5);
Vs(:, i) = x;

% Check if equilibrium conditions are satisfied
if theta<1 && Ds(i)<0 
    isEquilibrium(i) = 1;
elseif theta>1 && Ds(i)>0
    isEquilibrium(i) = 1;
end

% Compute prices
% the price is 1e10 if the surplus is negative
Sigma_matrix = [-1, 0, -1, 0, 0, 2, 0; -1, 0, 0, 0, 0, 1, -1; -1, 1, 0, 0, -1, 1, 0;... 
                0, -1, -1, 0, 0, 2, 0; 0, -1, 0, 0, 0, 1, -1; 0, 0, 0, 0, -1, 1, 0;...
                0, 0, 0, -1, 0, 1, 0; 0, 0, 1, -1, 0, 0, -1; 0, 1, 1, -1, -1, 0, 0];
            
Sigmas = Sigma_matrix*x;

temp = [eta*(x(6)-x(1))-(1-eta)*(x(6)-x(3)); eta*(x(6)-x(1))-(1-eta)*(-x(7)); eta*(x(6)-x(1))-(1-eta)*(x(2)-x(5));...
        eta*(x(6)-x(2))-(1-eta)*(x(6)-x(3)); eta*(x(6)-x(2))-(1-eta)*(-x(7)); eta*(x(6)-x(2))-(1-eta)*(x(2)-x(5));...
        eta*(x(3)-x(4))-(1-eta)*(x(6)-x(3)); eta*(x(3)-x(4))-(1-eta)*(-x(7)); eta*(x(3)-x(4))-(1-eta)*(x(2)-x(5))];

temp2 = Sigmas>=0;

ps(:, i) = temp.*temp2+1e10*(1-temp2);

if theta>1
    ave_price(i) = (mu(theta)-q(theta))/(g+mu(theta))*(1/theta*temp(1)*temp2(1)+(theta-1)/theta*temp(7)*temp2(7))+...
        (g+q(theta))/(g+mu(theta))*(1/theta*temp(2)*temp2(2)+(theta-1)/theta*temp(8)*temp2(8));
elseif theta<1
    ave_price(i) = (g+mu(theta))/(g+q(theta))*((1-theta)*temp(3)*temp2(3)+theta*temp(2)*temp2(2))+...
        (q(theta)-mu(theta))/(g+q(theta))*((1-theta)*temp(6)*temp2(6)+theta*temp(5)*temp2(5));
    
end

V_old = x;
    
end    

%% Make a plot of the difference between V^B1 and V^S1 on a grid of thetas
logthetas = log(thetas);
zero_line = zeros(length(thetas));

logth1 = log(th1);
logth2 = log(th2);

figure;
plot(logthetas, Ds, 'LineStyle', '-', 'Color', 'k', 'LineWidth', 3);
hold on
temp = get(gca,'ylim')*1.2;
plot([logth1 logth1], temp, 'LineStyle', '--', 'Color', 'k')
hold on
plot([logth2 logth2], temp, 'LineStyle', '-.', 'Color', 'k')
xlim([min(logthetas) max(logthetas)])
ylim([min(Ds)*1.1 max(Ds)*1.1])
xlabel('(log) \theta');
ylabel('D(\theta)=V^{B1}-V^{S1}');
hold on
plot(logthetas, zero_line, 'LineStyle', ':', 'Color', 'k', 'LineWidth', 1.2);


